@@ -30,12 +30,13 @@
 #endif
 #include "version.h"
 
-const char *copy = "\
+static const char *copy = "\
 Copyright (c) %s Tama Communications Corporation\n\
 License GPLv3+: GNU GPL version 3 or later <http://www.gnu.org/licenses/gpl.html>\n\
 This is free software; you are free to change and redistribute it.\n\
 There is NO WARRANTY, to the extent permitted by law.\n\
 ";
+static const char *sysname = "Global";
 /**
  * get_version: get version string.
  */
@@ -62,7 +63,7 @@ version(const char *name, const int verbose)
 	if (qflag)
 		fprintf(stdout, "%s\n", VERSION);
 	else {
-		fprintf(stdout, "%s (%s) %s\n", name, PACKAGE_NAME, VERSION);
+		fprintf(stdout, "%s (%s) %s\n", name, sysname, VERSION);
 		fprintf(stdout, "Powered by Berkeley DB 1.85");
 #ifdef USE_SQLITE3
 		fprintf(stdout, " and SQLite3 %s", sqlite3_version);
